@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import sys
+from unittest import mock
 
-import mock
 from neutron.agent import rpc as agent_rpc
-from neutron.common import topics
 from neutron import wsgi
+from neutron_lib.agent import topics
 from oslo_config import cfg
 import webob
 
